@@ -61,6 +61,9 @@ signals:
     //! Emitted when the registered phones changes.
     void regPhoneChange(const QStringList &phones, int index);
 
+    // When the user dismisses the message box, we reroute the signal
+    void sigMessageBoxDone(bool ok);
+
 public slots:
     void setStatus (const QString &strText, int timeout = 3000);
 
@@ -163,7 +166,8 @@ private slots:
     void onMqThreadFinished();
 
     //! Invoked when the message box is done
-    void onSigMsgBoxDone(bool ok = true);
+    void onSigMsgBoxOk();
+    void onSigMsgBoxCancel();
 
     //! Invoked when the Call initiators list changes
     void onCallInitiatorsChange(bool bSave = true);
@@ -208,6 +212,11 @@ private slots:
     //! Invoked when ANY button is clicked and requires a haptic feedback
     void onBtnClickFroHapticFeedback();
 
+    //! User clicks ok/cancel after entering TFA pin code.
+    void onPinMsgBoxDone(bool ok);
+    //! User clicks ok/cancel after entering application specific password.
+    void onAppPassMsgBoxDone(bool ok);
+
 private:
     void initLogging ();
 
@@ -216,7 +225,7 @@ private:
     bool connectSettingsSignals();
 
 
-    void initContacts ();
+    void initContacts (const QString &contactsPass);
     void deinitContacts ();
 
     void initInbox ();
@@ -231,8 +240,6 @@ private:
 
     void playVmail (const QString &strFile);
 
-    void showMsgBox (const QString &strMessage);
-
     void setUsername(const QString &strUsername);
     void setPassword(const QString &strPassword);
 
@@ -251,6 +258,11 @@ private:
     //! Request quit in the app
     void requestQuit();
 
+    void showMsgBox (const QString &strMessage, bool inputBox);
+    void showMsgBox (const QString &strMessage);
+    void showInputBox (const QString &strMessage);
+    void onSigMsgBoxDone(bool ok = true);
+
 private:
     GVApi           gvApi;
 
@@ -337,6 +349,9 @@ private:
     //! Use this to format a progress string:
     //  QString("Progress : %1%").arg(progressPercent);
     QString         gvApiProgressString;
+
+    // Context to be passed between invoking the inputbox and dismissing it
+    void           *inputBoxCtx;
 };
 
 #endif // MAINWINDOW_H
